Schedule

Struct Schedule 

pub struct Schedule<In, Out> { /* private fields */ }
A Schedule determines whether to continue and how long to wait. It maintains internal state. For simplicity in this MVP, we use a trait object or a struct with a closure that returns state. Refined: Schedule<In, Out> We need to run it. Schedule with generic composition support

Implementations

Source

impl<In, Out> Schedule<In, Out>
where In: Send + Sync + 'static, Out: Send + Sync + 'static + Clone,

pub fn recurs(n: usize) -> Schedule<In, usize>

pub fn spaced(duration: Duration) -> Schedule<In, ()>

pub fn exponential(base: Duration, factor: f64) -> Schedule<In, Duration>

pub fn jittered(self, min: f64, max: f64) -> Schedule<In, Out>
where Out: Send + Sync + 'static + Clone,

pub fn intersect<Out2>( self, other: Schedule<In, Out2>, ) -> Schedule<In, (Out, Out2)>
where Out2: Send + Sync + 'static + Clone, In: Clone,

pub fn union<Out2>( self, other: Schedule<In, Out2>, ) -> Schedule<In, (Option<Out>, Option<Out2>)>
where Out2: Send + Sync + 'static + Clone, In: Clone,

pub fn driver(&self) -> Box<dyn ScheduleDriver<In, Out> + Send + Sync>