Module core
Source - Ctx
- Runtime Context passed down the call stack.
- Deferred
- Effect
- Env
- A generic environment container storing services by type.
- EnvRef
- The environment reference.
Currently a simple wrapper, will expand to a type map later.
- Fiber
- A handle to a running fiber.
- FiberId
- Represents a fiber identifier.
- FiberRef
- A thread-local variable for fibers.
- LiveClock
- Queue
- A wrapper around a bounded Tokio channel.
- Ref
- A generic mutable reference that is safe to share between fibers.
Unlike FiberRef, this is shared state.
- ScopeHandle
- StdMutex
- A mutual exclusion primitive useful for protecting shared data
- TokioMutex
- An asynchronous
Mutex-like type.
- Cause
- Exit
- The result of an Effect execution.
- ScopeExit
- Clock
- Abstraction for time.
- Defect
- A defect is an untyped panic payload.